#
# spec file for package hledger
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hledger
%bcond_with tests
Name:           %{pkg_name}
Version:        1.10
Release:        1.2
Summary:        Command-line interface for the hledger accounting tool
License:        GPL-3.0-or-later
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Decimal-devel
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-base-compat-batteries-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cmdargs-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-csv-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-file-embed-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-haskeline-devel
BuildRequires:  ghc-here-devel
BuildRequires:  ghc-hledger-lib-devel
BuildRequires:  ghc-lucid-devel
BuildRequires:  ghc-megaparsec-devel
BuildRequires:  ghc-mtl-compat-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-old-time-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-shakespeare-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-tabular-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-terminfo-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utility-ht-devel
BuildRequires:  ghc-wizards-devel
%if %{with tests}
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
%endif

%description
This is hledger's command-line interface. Its basic function is to read a plain
text file describing financial transactions and produce useful reports.

hledger is a cross-platform program for tracking money, time, or any other
commodity, using double-entry accounting and a simple, editable file format.
It is inspired by and largely compatible with ledger(1). hledger provides
command-line, curses and web interfaces, and aims to be a reliable, practical
tool for daily use.

%package -n ghc-%{name}
Summary:        Haskell %{name} library
Group:          System/Libraries

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Group:          Development/Libraries/Haskell
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGES README.md
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGES README.md

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update hledger to version 1.10.
  User-visible changes in the hledger command line tool.
  [#] 1.10 (2018/6/30)
  * journal: many parse error messages have become more informative, and
    some now show the source line and error location.
  * journal: ;tag: is no longer parsed as a tag named ";tag" (#655)
  * journal: transaction price amounts having their own price amounts is
    now a parse error
  * journal: amounts with space as digit group separator and trailing whitespace
    now parse correctly (#780)
  * journal: in amounts containing digits and a single space, the space
    is now interpreted as a digit group separator, not a decimal separator (#749)
  * journal: in commodity/format/D directives, the amount must now include a decimal separator.
    When more precise control is needed over number parsing, our
    recommended solution is commodity directives. Commodity directives
    that don't specify the decimal separator leave things ambiguous,
    increasing the chance of misparsing numbers. In some cases it could
    cause amounts with a decimal point to be parsed as if with a digit
    group separator, so 1.234 became 1234.
    It seems the simple and really only way to do this reliably is to require
    an explicit decimal point character. Most folks probably do this already.
    Unfortunately, it makes another potential incompatiblity with ledger and
    beancount journals. But the error message will be clear and easy to
    work around.
  * journal: directives currently have diverse and somewhat tricky
    semantics, especially with multiple files.  The manual now describes
    their behaviour precisely.
  * journal: `alias` and `apply account` directives now affect `account` directives (#825)
  * journal: periodic transactions can now have all the usual transaction fields
    (status mark, code, description, comment), for generating more expressive
    forecast transactions.
  * journal: forecast transactions now have the generating period
    expression attached as a tag named "recur".
  * journal: periodic transactions now start on the first instance of the
    recurring date, rather than the day after the last regular transaction (#750)
  * journal: periodic transaction rules now allow period expressions relative to today's date
  * csv: amount-in/amount-out errors are more detailed
  * balance: --drop is now ignored when not in flat mode,
    rather than producing a corrupted report (#754)
  * budget: --drop now preserves the <unbudgeted> top-level account in --budget reports
  * register: in CSV output, the code field is now included (#746)
  * smart dates now allow  the YYYYMM format, and are better documented
  * use hledger-lib 1.10
* Tue May  1 2018 psimons@suse.com
- Update hledger to version 1.9.1.
  A more detailed change log is not available.
* Mon Apr  2 2018 psimons@suse.com
- Update hledger to version 1.9.
  A more detailed change log is not available.
* Tue Mar 13 2018 psimons@suse.com
- Update hledger to version 1.5.
  A more detailed change log is not available.
